CHANGES
=======

0.2 - 2012-04-17
----------------

- make sure execution errors are properly transmited and raised.
- fixed the pool of connectors - so every connector is correctly freed
- now workers can get extra options from the command-line

0.1 - 2012-04-05
----------------

- initial release.

